The Board of Veterans' Appeals Decision search results -- U.S. Department of Veterans Affairs
Author: VA Web Solutions Office
Keywords: VA, veterans affairs, search, search engine

skip to page content
Attention JAWS users. To access the menus on this page please preform the following steps. 1. Please switch JAWS auto forms mode to off. 2. Hit enter to expand a main menu option (Health, Benefits, etc). 3. To enter and activate the submenu links, hit the down arrow. You will now be able to tab or arrow up or down through the submenu options to access/activate the submenu links.
I AM A...

- For Veterans
- For Family Members & Spouses
- For Employees
- For Business
- Forms & Publications
- Jobs
- Volunteer or Donate
- Public & Intergovernmental Affairs

#### August 14, 2014 update

June 2014 Board of Veterans' Appeals decisions are now available in BVA Decision Search results.

#### Resources

Enter ZIP code here
Enter ZIP code here

# The Board of Veterans' Appeals Decision search results

Help
Find pages with...
these words:
this exact word or phrase:
any of these words:
none of these words:
results per page:
10 20 50
searched year(s) checked below (results per year):
2014 (25196) 2013 (33453) 2012 (40814) 2011 (43766) 2010 (45775) 2009 (49136) 2008 (44970) 2007 (41025) 2006 (40304) 2005 (35250) 2004 (34495) 2003 (36924) 2002 (18850) 2001 (27807) 2000 (34102) 1999 (36270) 1998 (38177) 1997 (43170) 1996 1995 1994 1993 1992
Page 1 of 669484 results
Citation Nr: 1429594 Decision Date: 06/17/14 Archive Date: 07/03/14 DOCKET NO. 11-05 016
www.va.gov/vetapp14/files4/1429594.txt
Citation Nr: 1429594 Decision Date: 06/17/14 Archive Date: 07/03/14 DOCKET NO. 11-05 016A DATE ) On appeal from the Department of Veterans Affairs Regional Office in Winston-Salem, North Carolina
Use our Viewer to open this file
Citation Nr: 1429593 Decision Date: 06/16/14 Archive Date: 07/03/14 DOCKET NO. 11-08 138
www.va.gov/vetapp14/files4/1429593.txt
Citation Nr: 1429593 Decision Date: 06/16/14 Archive Date: 07/03/14 DOCKET NO. 11-08 138 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Waco, Texas THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429592 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 13-16 280
www.va.gov/vetapp14/files4/1429592.txt
Citation Nr: 1429592 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 13-16 280 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Louis, Missouri THE ISSUES
Use our Viewer to open this file
Citation Nr: 1429591 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-22 296
www.va.gov/vetapp14/files4/1429591.txt
Citation Nr: 1429591 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-22 296 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Houston, Texas THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429590 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 13-34 313
www.va.gov/vetapp14/files4/1429590.txt
Citation Nr: 1429590 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 13-34 313 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Waco, Texas THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429589 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-17 411
www.va.gov/vetapp14/files4/1429589.txt
Citation Nr: 1429589 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-17 411 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Nashville, Tennessee THE ISSUES
Use our Viewer to open this file
Citation Nr: 1429588 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-28 586
www.va.gov/vetapp14/files4/1429588.txt
Citation Nr: 1429588 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-28 586 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Muskogee, Oklahoma THE ISSUES
Use our Viewer to open this file
Citation Nr: 1429587 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 06-07 745
www.va.gov/vetapp14/files4/1429587.txt
Citation Nr: 1429587 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 06-07 745 DATE ) On appeal from the Department of Veterans Affairs Regional Office in North Little Rock, Arkansas THE
Use our Viewer to open this file
Citation Nr: 1429586 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-19 921
www.va.gov/vetapp14/files4/1429586.txt
Citation Nr: 1429586 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-19 921 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Winston-Salem, North Carolina
Use our Viewer to open this file
Citation Nr: 1429585 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-13 307
www.va.gov/vetapp14/files4/1429585.txt
Citation Nr: 1429585 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-13 307 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Petersburg, Florida THE
Use our Viewer to open this file
Citation Nr: 1429583 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-21 998
www.va.gov/vetapp14/files4/1429583.txt
Citation Nr: 1429583 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-21 998 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Petersburg, Florida THE
Use our Viewer to open this file
Citation Nr: 1429584 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-01 368
www.va.gov/vetapp14/files4/1429584.txt
Citation Nr: 1429584 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-01 368 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Oakland, California THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429582 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-24 601
www.va.gov/vetapp14/files4/1429582.txt
Citation Nr: 1429582 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-24 601 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Winston-Salem, North Carolina
Use our Viewer to open this file
Citation Nr: 1429581 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-02 858
www.va.gov/vetapp14/files4/1429581.txt
Citation Nr: 1429581 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-02 858 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Atlanta, Georgia THE ISSUES 1.
Use our Viewer to open this file
Citation Nr: 1429580 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-04 701
www.va.gov/vetapp14/files4/1429580.txt
Citation Nr: 1429580 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-04 701 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Detroit, Michigan THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429579 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-05 009
www.va.gov/vetapp14/files4/1429579.txt
Citation Nr: 1429579 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-05 009 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Lincoln, Nebraska THE ISSUES 1.
Use our Viewer to open this file
Citation Nr: 1429578 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-18 486
www.va.gov/vetapp14/files4/1429578.txt
Citation Nr: 1429578 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-18 486 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Montgomery, Alabama THE ISSUES
Use our Viewer to open this file
Citation Nr: 1429577 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-36 887
www.va.gov/vetapp14/files4/1429577.txt
Citation Nr: 1429577 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-36 887 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Waco, Texas THE ISSUES 1.
Use our Viewer to open this file
Citation Nr: 1429576 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-19 064
www.va.gov/vetapp14/files4/1429576.txt
Citation Nr: 1429576 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-19 064 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Cleveland, Ohio THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429575 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 13-13 189
www.va.gov/vetapp14/files4/1429575.txt
Citation Nr: 1429575 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 13-13 189 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Philadelphia, Pennsylvania THE
Use our Viewer to open this file
Citation Nr: 1429574 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 03-22 545
www.va.gov/vetapp14/files4/1429574.txt
Citation Nr: 1429574 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 03-22 545 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Columbia, South Carolina THE
Use our Viewer to open this file
Citation Nr: 1429573 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 06-10 830
www.va.gov/vetapp14/files4/1429573.txt
Citation Nr: 1429573 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 06-10 830 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Louis, Missouri THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429572 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-23 237
www.va.gov/vetapp14/files4/1429572.txt
Citation Nr: 1429572 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-23 237 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Roanoke, Virginia THE ISSUES 1.
Use our Viewer to open this file
Citation Nr: 1429571 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-28 558
www.va.gov/vetapp14/files4/1429571.txt
Citation Nr: 1429571 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-28 558 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Petersburg, Florida THE
Use our Viewer to open this file
Citation Nr: 1429570 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-10 362
www.va.gov/vetapp14/files4/1429570.txt
Citation Nr: 1429570 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-10 362 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Atlanta, Georgia THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429569 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-06 718
www.va.gov/vetapp14/files4/1429569.txt
Citation Nr: 1429569 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-06 718 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Houston, Texas THE ISSUES 1.
Use our Viewer to open this file
Citation Nr: 1429568 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-00 198
www.va.gov/vetapp14/files4/1429568.txt
Citation Nr: 1429568 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-00 198 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Denver, Colorado THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429567 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-15 036
www.va.gov/vetapp14/files4/1429567.txt
Citation Nr: 1429567 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-15 036 DATE ) On appeal from the Department of Veterans Affairs Regional Office in New York, New York THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429566 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-15 128
www.va.gov/vetapp14/files4/1429566.txt
Citation Nr: 1429566 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-15 128 DATE On appeal from the Department of Veterans Affairs Regional Office in Waco, Texas THE ISSUE Entitlement
Use our Viewer to open this file
Citation Nr: 1429565 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-05 735
www.va.gov/vetapp14/files4/1429565.txt
Citation Nr: 1429565 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-05 735 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Petersburg, Florida THE
Use our Viewer to open this file
Citation Nr: 1429564 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-34 980
www.va.gov/vetapp14/files4/1429564.txt
Citation Nr: 1429564 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-34 980 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Waco, Texas THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429563 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-34 047
www.va.gov/vetapp14/files4/1429563.txt
Citation Nr: 1429563 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-34 047 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Honolulu, Hawaii THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429562 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-11 318
www.va.gov/vetapp14/files4/1429562.txt
Citation Nr: 1429562 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-11 318 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Petersburg, Florida THE
Use our Viewer to open this file
Citation Nr: 1429561 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-24 027
www.va.gov/vetapp14/files4/1429561.txt
Citation Nr: 1429561 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-24 027 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Roanoke, Virginia THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429560 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-44 728
www.va.gov/vetapp14/files4/1429560.txt
Citation Nr: 1429560 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-44 728 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Oakland, California THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429559 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 06-30 658
www.va.gov/vetapp14/files4/1429559.txt
Citation Nr: 1429559 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 06-30 658 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Roanoke, Virginia THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429558 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-16 318
www.va.gov/vetapp14/files4/1429558.txt
Citation Nr: 1429558 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-16 318 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Waco, Texas THE ISSUES 1.
Use our Viewer to open this file
Citation Nr: 1429557 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 12-28 213
www.va.gov/vetapp14/files4/1429557.txt
Citation Nr: 1429557 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 12-28 213 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Muskogee, Oklahoma THE ISSUES
Use our Viewer to open this file
Citation Nr: 1429556 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 12-35 381
www.va.gov/vetapp14/files4/1429556.txt
Citation Nr: 1429556 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 12-35 381 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Louis, Missouri THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429555 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-14 017
www.va.gov/vetapp14/files4/1429555.txt
Citation Nr: 1429555 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-14 017 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Jackson, Mississippi THE ISSUES
Use our Viewer to open this file
Citation Nr: 1429554 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-12 076
www.va.gov/vetapp14/files4/1429554.txt
Citation Nr: 1429554 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-12 076 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Des Moines, Iowa THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429553 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 12-01 713
www.va.gov/vetapp14/files4/1429553.txt
Citation Nr: 1429553 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 12-01 713 DATE ) On appeal from the Department of Veterans Affairs Regional Office in New York, New York THE ISSUES
Use our Viewer to open this file
Citation Nr: 1429552 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-29 451
www.va.gov/vetapp14/files4/1429552.txt
Citation Nr: 1429552 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-29 451 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Waco, Texas THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429551 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-02 292
www.va.gov/vetapp14/files4/1429551.txt
Citation Nr: 1429551 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-02 292 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Muskogee, Oklahoma THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429550 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-13 121
www.va.gov/vetapp14/files4/1429550.txt
Citation Nr: 1429550 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 11-13 121 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Lincoln, Nebraska THE ISSUES 1.
Use our Viewer to open this file
Citation Nr: 1429549 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-34 229
www.va.gov/vetapp14/files4/1429549.txt
Citation Nr: 1429549 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 10-34 229 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Huntington, West Virginia THE
Use our Viewer to open this file
Citation Nr: 1429548 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-35 671
www.va.gov/vetapp14/files4/1429548.txt
Citation Nr: 1429548 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 07-35 671 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Seattle, Washington THE ISSUES
Use our Viewer to open this file
Citation Nr: 1429547 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-13 564
www.va.gov/vetapp14/files4/1429547.txt
Citation Nr: 1429547 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 08-13 564 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Waco, Texas THE ISSUES 1.
Use our Viewer to open this file
Citation Nr: 1429546 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-10 043
www.va.gov/vetapp14/files4/1429546.txt
Citation Nr: 1429546 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 09-10 043 DATE ) On appeal from the Department of Veterans Affairs Regional Office in St. Louis, Missouri THE ISSUE
Use our Viewer to open this file
Citation Nr: 1429545 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 93-06 994
www.va.gov/vetapp14/files4/1429545.txt
Citation Nr: 1429545 Decision Date: 06/30/14 Archive Date: 07/03/14 DOCKET NO. 93-06 994 DATE ) On appeal from the Department of Veterans Affairs Regional Office in Huntington, West Virginia THE
Use our Viewer to open this file
Results 1 - 50 displayed 1 2 3 4 5 6 7 8 9 10 Next
return to top